powered by
Switch a focal mechanism so the auxilliary plane is the nodal plane.
flipnodal(s1, d1, r1)
Strike
Dip
Rake
List:
Fuunction is used for orienting a set of fault planes to line up according to a geologic interpretation.
# NOT RUN { s=65 d=25 r=13 mc = CONVERTSDR(s,d,r ) mc2 = flipnodal(s, d, r) # }
Run the code above in your browser using DataLab